# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2018-09-26 12:06

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('dbmail', '0014_auto_20170801_1206'),
    ]

    operations = [
        migrations.AlterField(
            model_name='mailgroupemail',
            name='email',
            field=models.CharField(help_text='For sms/tts you must specify number', max_length=75, verbose_name='Email'),
        ),
        migrations.AlterField(
            model_name='maillog',
            name='backend',
            field=models.CharField(choices=[('bot', 'dbmail.backends.bot'), ('mail', 'dbmail.backends.mail'), ('push', 'dbmail.backends.push'), ('sms', 'dbmail.backends.sms'), ('tts', 'dbmail.backends.tts')], db_index=True, default='mail', editable=False, max_length=25, verbose_name='Backend'),
        ),
        migrations.AlterField(
            model_name='maillogemail',
            name='mail_type',
            field=models.CharField(choices=[('cc', 'CC'), ('bcc', 'BCC'), ('to', 'TO')], max_length=3, verbose_name='Mail type'),
        ),
        migrations.AlterField(
            model_name='mailsubscription',
            name='data',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='mailsubscription',
            name='end_hour',
            field=models.CharField(default='23:59', max_length=5, verbose_name='End hour'),
        ),
        migrations.AlterField(
            model_name='mailsubscription',
            name='start_hour',
            field=models.CharField(default='00:00', max_length=5, verbose_name='Start hour'),
        ),
        migrations.AlterField(
            model_name='mailtemplate',
            name='bcc_email',
            field=models.ManyToManyField(blank=True, help_text='Blind carbon copy', to='dbmail.MailBcc', verbose_name='Bcc'),
        ),
        migrations.AlterField(
            model_name='mailtemplate',
            name='category',
            field=models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.CASCADE, to='dbmail.MailCategory', verbose_name='Category'),
        ),
        migrations.AlterField(
            model_name='mailtemplate',
            name='from_email',
            field=models.ForeignKey(blank=True, default=None, help_text='If not specified, then used default.', null=True, on_delete=django.db.models.deletion.SET_NULL, to='dbmail.MailFromEmail', verbose_name='Message from'),
        ),
        migrations.AlterField(
            model_name='signal',
            name='rules',
            field=models.TextField(blank=True, default='{{ instance.email }}', help_text='Template should return email to send message. Example:{% if instance.is_active %}{{ instance.email }}{% endif %}.You can return a multiple emails separated by commas.', null=True, verbose_name='Rules'),
        ),
        migrations.AlterField(
            model_name='signal',
            name='signal',
            field=models.CharField(choices=[('pre_save', 'pre_save'), ('post_save', 'post_save'), ('pre_delete', 'pre_delete'), ('post_delete', 'post_delete'), ('m2m_changed', 'm2m_changed')], default='post_save', max_length=15, verbose_name='Signal'),
        ),
        migrations.AlterField(
            model_name='signal',
            name='interval',
            field=models.PositiveIntegerField(help_text='Specify interval to send messages after sometime. That very helpful for mailing on enterprise products.Interval must be set in the seconds.', verbose_name='Send interval', default=0),
        ),
        migrations.AlterField(
            model_name='mailtemplate',
            name='interval',
            field=models.PositiveIntegerField(help_text='\n            Specify interval to send messages after sometime.\n            Interval must be set in the seconds.\n            ', verbose_name='Send interval', default=0),
        ),
    ]




# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-08-01 12:06
from __future__ import unicode_literals

from dbmail.defaults import SORTED_BACKEND_CHOICES, BACKENDS_MODEL_CHOICES, BACKEND
from dbmail.models import SubscriptionDataField
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('dbmail', '0013_auto_20160923_2201'),
    ]

    operations = [
        migrations.AlterField(
            model_name='maillog',
            name='backend',
            field=models.CharField(choices=SORTED_BACKEND_CHOICES, db_index=True, default=b'mail', editable=False, max_length=25, verbose_name='Backend'),
        ),
        migrations.AlterField(
            model_name='mailsubscription',
            name='address',
            field=models.CharField(db_index=True, help_text='Must be phone number/email/token', max_length=350, verbose_name='Address'),
        ),
        migrations.AlterField(
            model_name='mailsubscription',
            name='backend',
            field=models.CharField(choices=BACKENDS_MODEL_CHOICES, default=BACKEND.get('mail'), max_length=50, verbose_name='Backend'),
        ),
        migrations.AlterField(
            model_name='mailsubscription',
            name='data',
            field=SubscriptionDataField(blank=True, default=dict, null=True),
        ),
        migrations.AlterField(
            model_name='mailsubscription',
            name='title',
            field=models.CharField(blank=True, max_length=350, null=True),
        ),
        migrations.AlterField(
            model_name='mailtemplate',
            name='category',
            field=models.ForeignKey(blank=True, default=2, null=True, on_delete=django.db.models.deletion.CASCADE, to='dbmail.MailCategory', verbose_name='Category'),
        ),
        migrations.AlterField(
            model_name='mailtemplate',
            name='from_email',
            field=models.ForeignKey(blank=True, default=2, help_text='If not specified, then used default.', null=True, on_delete=django.db.models.deletion.SET_NULL, to='dbmail.MailFromEmail', verbose_name='Message from'),
        ),
    ]
